//
//  ViewController.m
//  randompic
//
//  Created by David Oster on 6/23/12.
//  Copyright (c) 2012 Google. All rights reserved.
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

#import "ViewController.h"
#import <AssetsLibrary/AssetsLibrary.h>

static int Random(int lo, int hi) {
  static BOOL isFirstTime = YES;
  if (isFirstTime) {
    isFirstTime = NO;
    double dseed = [NSDate timeIntervalSinceReferenceDate];
    float fseed = fmod(dseed, 1000000.);
    unsigned seed = * (unsigned *) &fseed;
    srandom(seed);
  }
  return lo + random() % (1+hi-lo);
}



@interface ViewController ()
@property (nonatomic, retain) NSMutableArray *assets;
@property (nonatomic, retain) ALAssetsLibrary *library;

- (void)randomPic;

@end

@implementation ViewController
@synthesize assets = _assets;
@synthesize library = _library;

- (void)dealloc {
  [_assets release];
  [_library release];
  [super dealloc];
}

- (void)loadView {
  [self setTitle:@"Random Pic"];

  CGRect frame = CGRectMake(0, 0, 200, 200);
  UIImageView *imageView = [[[UIImageView alloc] initWithFrame:frame] autorelease];
  [imageView setUserInteractionEnabled:YES];
  [imageView setAutoresizingMask:0x3F];
  [imageView setContentMode:UIViewContentModeCenter];
  UIButton *button = [UIButton buttonWithType:UIButtonTypeRoundedRect];
  [button setFrame:CGRectMake(20, 20, 150, 30)];
  [button addTarget:self action:@selector(randomPic) forControlEvents:UIControlEventTouchUpInside];
  [button setAutoresizingMask:UIViewAutoresizingFlexibleLeftMargin | UIViewAutoresizingFlexibleBottomMargin];
  [button setTitle:@"Random Pic" forState:UIControlStateNormal];
  [imageView addSubview:button];
  [self setView:imageView];

  [self setLibrary: [[ALAssetsLibrary alloc] init]];
  [self setAssets:[NSMutableArray array]];

  [_library enumerateGroupsWithTypes:ALAssetsGroupAll
                          usingBlock:^(ALAssetsGroup *group, BOOL *stop) {
    NSString *name = [group valueForProperty:ALAssetsGroupPropertyName];
    if ([name length]) {
      [group enumerateAssetsUsingBlock:^(ALAsset *asset, NSUInteger index, BOOL *stop) {
        if ([[asset valueForProperty:ALAssetPropertyType] isEqual:ALAssetTypePhoto]) {
          [[self assets] addObject:asset];
        }
      }];
    }
    if (nil == group) {
      [self randomPic];
    }
  } failureBlock:^(NSError *error) {
  }];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation{
  return YES;
}

- (void)randomPic {
  if ([_assets count]) {
    int index = Random(0, [_assets count]-1);
    ALAsset *asset = [_assets objectAtIndex:index];
    CGImageRef cgImage = [[asset defaultRepresentation] fullResolutionImage];
    UIImage *image = nil;
    if (cgImage) {
      NSNumber *orientationN = [asset valueForProperty:ALAssetPropertyOrientation];
      UIImageOrientation orientation = (UIImageOrientation)[orientationN intValue];
      image = [UIImage imageWithCGImage:cgImage scale:1 orientation:orientation];
    }
    if (image) {
      [(UIImageView *)[self view] setImage:image];
    }
  }
}

@end
